Actions, Resources, and Condition Keys for Amazon Kinesis Video Streams - AWS Identity and Access Management
Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Kinesis Video Streams.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

AWS Identity and Access Management
User Guide

# Actions, Resources, and Condition Keys for Amazon Kinesis Video Streams

Amazon Kinesis Video Streams (service prefix: `kinesisvideo`) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service.

- View a list of the API operations available for this service.

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by Amazon Kinesis Video Streams
- Resources Defined by Amazon Kinesis Video Streams
- Condition Keys for Amazon Kinesis Video Streams

## Actions Defined by Amazon Kinesis Video Streams

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table.

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
CreateStream | Create a Kinesis video stream. | Write | stream* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteStream | Delete an existing Kinesis video stream. | Write | stream* |  |
DescribeStream | Describe the specified Kinesis video stream. | List | stream* |  |
GetDASHStreamingSessionURL | Creates a URL for MPEG-DASH video streaming. | Read | stream* |  |
GetDataEndpoint | Gets an endpoint for a specified stream for either reading or writing media data to Kinesis Video Streams. | Read | stream* |  |
GetHLSStreamingSessionURL | Creates a URL for HLS video streaming. | Read | stream* |  |
GetMedia | Returns media content of a Kinesis video stream. | Read | stream* |  |
GetMediaForFragmentList | Read and return media data only from persisted storage. | Read | stream* |  |
ListFragments | List the fragments from archival storage based on the pagination token or selector type with range specified. | List | stream* |  |
ListStreams | List your Kinesis video streams. | List |  |  |
ListTagsForStream | Fetch the tags associated with Kinesis video stream. | Read | stream* |  |
PutMedia | Send media data to a Kinesis video stream. | Write | stream* |  |
TagStream | Attach set of tags to your Kinesis video streams. | Tagging | stream* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagStream | Remove one or more tags from your Kinesis video streams. | Tagging | stream* |  |
| aws:TagKeys |
UpdateDataRetention | Update the data retention period of your Kinesis video stream. | Write | stream* |  |
UpdateStream | Update an existing Kinesis video stream. | Write | stream* |  |

## Resources Defined by Amazon Kinesis Video Streams

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table.

Resource Types | ARN | Condition Keys
--- | --- | ---
stream | `arn:${Partition}:kinesisvideo:${Region}:${Account}:stream/${StreamName}/${CreationTime}` | aws:ResourceTag/${TagKey}

## Condition Keys for Amazon Kinesis Video Streams

Amazon Kinesis Video Streams defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table.

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference.

Condition Keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters requests based on the allowed set of values for each of the tags | String
aws:ResourceTag/${TagKey} | Filters actions based on tag-value assoicated with the stream. | String
aws:TagKeys | Filters requests based on the presence of mandatory tag keys in the request | String

On this page:

- Actions Defined by Amazon Kinesis Video Streams
- Resources Defined by Amazon Kinesis Video Streams
- Condition Keys for Amazon Kinesis Video Streams

We use cookies to provide and improve our services. By using our site, you consent to cookies. Learn more